<?php


namespace Controller;

use Exception\CustomException;
use Traits\TResponse;
use Zeedhi\Framework\DTO\Request;
use Service\StructureConfiguration as StructureConfigurationService;

class StructureConfiguration
{
    use TResponse;
    /**
     * @var StructureConfigurationService
     */
    private $structureConfigurationService;

    public function __construct(StructureConfigurationService $structureConfigurationService)
    {
        $this->structureConfigurationService = $structureConfigurationService;
    }

    public function findStructureConfiguration(Request $request)
    {
        try {
            $result = $this->structureConfigurationService->findStructureConfiguration();
            $this->sendResponse($result, 200);
        } catch (\Exception $e) {
            $this->sendResponse($this->createResponseError($e), 500);
        }
    }

    
    public function saveStructureConfiguration(Request $request)
    {
        try {
            $rows = $request->getParameters()['DATA'];
            $result = $this->structureConfigurationService->saveStructureConfiguration($rows);
            $this->sendResponse($result, 200);
        } catch (\Exception $e) {
            $this->sendResponse($this->createResponseError($e), 500);
        }
    }

    public function removeStructureType(Request $request)
    {
        try {
            $rows = $request->getParameters()['DATA'];
            $isInUse = $this->structureConfigurationService->checkStructureTypeInUser($rows);
            if(!$isInUse){
                $result = $this->structureConfigurationService->removeStructureType($rows);   
            }else{
                throw new CustomException('ERR_NOT_POSSIBLE_TO_CREATE_ISSUE_BECAUSE_CLIENT');
            }
            $this->sendResponse($result, 200);
        } catch (\Exception $e) {
            $this->sendResponse($this->createResponseError($e), 500);
        }
    }
}
