<?php

namespace Repository;

use Doctrine\ORM\EntityManager;
use Util\InstanceProvider;
use Doctrine\DBAL\Connection;
use Teknisa\Model\Traits\TQuery;

class Task {
    use TQuery;

    /**
     * @var EntityManager
     */
    private $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        $this->entityManager = $entityManager;
    }

    public function findIssueClassification($organizationId, $filter = '', $classificationFilter = array(0)) {

        $query = <<<SQL
        SELECT *
          FROM (SELECT CLA.ID, CLA.LABEL
                  FROM CLASSIFICATION CLA
                  JOIN CLASSIFICATION_PROJECT_TYPE CPT ON (CPT.CLASSIFICATION = CLA.ID AND CPT.TYPE = 'P')
                  JOIN PROJECT_TYPE PRT ON (PRT.ID = CPT.PROJECT_TYPE)
                 WHERE PRT.EXTERNALTYPE = 'P'
                   AND CLA.IS_TASK = 'Y'
                   AND CLA.CONTROL IS NULL
                   AND CLA.ORGANIZATION = :ORGANIZATION_ID
                   AND CLA.ID NOT IN (:CLASSIFICATION_FILTER)
              GROUP BY CLA.LABEL, CLA.ID
              ORDER BY CLA.LABEL)
		 WHERE 1 = 1
			   $filter
      ORDER BY LABEL
SQL;

		$params = array(
			'ORGANIZATION_ID'       => $organizationId,
			'CLASSIFICATION_FILTER' => $classificationFilter
		);
        $paramTypes = array(
            'CLASSIFICATION_FILTER' => Connection::PARAM_STR_ARRAY
        );
        return $this->createAndExecuteQueryAndBuildResponseData(InstanceProvider::getEntityManager(), $query, $params, $paramTypes);
	}

    public function findTaskStatus($organizationId,$filtersString = ''){
        $query = <<<SQL
        SELECT * FROM (
            SELECT 	TS.ID, TS.ORGANIZATION, TS.CONTROL, TS.LABEL, TS.TASK_TYPE, TS.IS_ISSUE,IS_TASK,
                        TS.CREATED_BY, TS.CREATED_AT, TS.UPDATED_BY, TS.UPDATED_AT,
                        TT.LABEL AS TASK_TYPE_LABEL, TT.INITIAL_TASK_STATUS,TS.CONTROL AS OLD_CONTROL,
                        (CASE WHEN TS.ID = TT.INITIAL_TASK_STATUS THEN 'Y' ELSE 'N' END) AS IS_INITIAL,
                        TS.USED_IN_TASK, TS.USED_IN_ISSUE
              FROM	    TASK_STATUS TS
              LEFT JOIN TASK_TYPE TT ON (TS.TASK_TYPE = TT.ID)
              WHERE	    TS.ORGANIZATION = :organizationId
              AND       TS.IS_PROJECT = 'N')
        WHERE 1=1
        $filtersString
        ORDER BY ID ASC
SQL;
        $params = array(
            'organizationId' => $organizationId
        );
        $result = $this->createAndExecuteQueryAndBuildResponseData(InstanceProvider::getEntityManager(), $query, $params);
        return $result;
    }
}
